<?php
/**
 * Plugin Name: Inboxify Form Connector
 * Description: Connect form plugins to Inboxify.
 * Version: 1.0.1
 * Author: Inboxify
 * Author URI: https://www.inboxify.eu
 * Text Domain: inboxify-form-connector
 * Domain Path: /languages
 * Requires at least: 6.2
 * Requires PHP: 8.0
 * License: GPLv2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 */

if ( ! defined( 'ABSPATH' ) ) exit;

define('INBOXIFY_FC_PLUGIN_VERSION', '1.0.1');
define('INBOXIFY_FC_PLUGIN_PATH', plugin_dir_path(__FILE__));
define('INBOXIFY_FC_API_URL', 'https://api.inboxify.eu');

require_once INBOXIFY_FC_PLUGIN_PATH . 'includes/api-handler.php';
require_once INBOXIFY_FC_PLUGIN_PATH . 'includes/mappings-handler.php';
require_once INBOXIFY_FC_PLUGIN_PATH . 'includes/inboxify-cf7-handler.php';
require_once INBOXIFY_FC_PLUGIN_PATH . 'includes/inboxify-wpforms-handler.php';
require_once INBOXIFY_FC_PLUGIN_PATH . 'includes/inboxify-ninjaforms-handler.php';
require_once INBOXIFY_FC_PLUGIN_PATH . 'includes/config/field-config.php';
require_once INBOXIFY_FC_PLUGIN_PATH . 'includes/migration.php';

register_activation_hook(__FILE__, function () {
    global $wp_version;

    $min_php = '8.0';
    $min_wp  = '6.2';

    if (version_compare(PHP_VERSION, $min_php, '<')) {
        deactivate_plugins(plugin_basename(__FILE__));
        wp_die(
            sprintf(
                /* translators: %1$s = required PHP version, %2$s = current PHP version */
                esc_html__('Inboxify Form Connector requires PHP %1$s or higher. You are running %2$s.', 'inboxify-form-connector'),
                esc_html($min_php),
                esc_html(PHP_VERSION)
            ),
            esc_html__('Plugin activation failed', 'inboxify-form-connector'),
            ['back_link' => true]
        );
    }

    if (version_compare($wp_version, $min_wp, '<')) {
        deactivate_plugins(plugin_basename(__FILE__));
        wp_die(
            sprintf(
                /* translators: %1$s = required WordPress version, %2$s = current WordPress version */
                esc_html__('Inboxify Form Connector requires WordPress %1$s or higher. You are running %2$s.', 'inboxify-form-connector'),
                esc_html($min_wp),
                esc_html($wp_version)
            ),
            esc_html__('Plugin activation failed', 'inboxify-form-connector'),
            ['back_link' => true]
        );
    }

    inboxify_fc_migrate_old_options();
});

function inboxify_fc_enqueue_admin_assets($hook) {
    if ($hook === 'toplevel_page_inboxify-form-connector') {
        wp_enqueue_script('inboxify-admin-js', plugins_url('/assets/js/admin.js', __FILE__), ['jquery'], INBOXIFY_FC_PLUGIN_VERSION, true);
        wp_localize_script('inboxify-admin-js', 'inboxify_fc_ajax_object', [
            'ajax_url' => admin_url('admin-ajax.php'),
            'nonce'    => wp_create_nonce('inboxify_nonce'),
        ]);
      
        wp_localize_script('inboxify-admin-js', 'inboxify_fc_i18n', [
            'apiConnected'         => __('API connected!', 'inboxify-form-connector'),
            'apiError'             => __('Error: ', 'inboxify-form-connector'),
            'notConnected'         => __('Inboxify is not connected:', 'inboxify-form-connector'),
            'selectForm'           => __('Select a form', 'inboxify-form-connector'),
            'alreadyMapped'        => __('(already mapped)', 'inboxify-form-connector'),
            'selectList'           => __('Select a list', 'inboxify-form-connector'),
            'notMapped'            => __('Not mapped', 'inboxify-form-connector'),
            'mappingSaved'         => __('Mapping saved!', 'inboxify-form-connector'),
            'noMappingsFound'      => __('No mappings found.', 'inboxify-form-connector'),
            'deleteMappingConfirm' => __('Are you sure you want to delete this mapping?', 'inboxify-form-connector'),
            'mappingDeleted'       => __('Mapping deleted!', 'inboxify-form-connector'),
            'editBlocked'          => __('You cannot edit this mapping because the connection to the Inboxify API is missing.', 'inboxify-form-connector'),
            'editMapping'          => __('Edit mapping', 'inboxify-form-connector'),
            'newMapping'           => __('New mapping', 'inboxify-form-connector'),
            'addMapping'           => __('Add mapping', 'inboxify-form-connector'),
            'delete' 	           => __('Delete', 'inboxify-form-connector'),
            'save'                 => __('Save', 'inboxify-form-connector'),
            'unknownError'         => __('Unknown error.', 'inboxify-form-connector'),
            /* translators: %s = form label */
            'editMappingFor'       => __('Edit mapping for %s', 'inboxify-form-connector'),
            /* translators: %s = error message */
            'errorFetchingMappings' => __('Error fetching mappings: %s', 'inboxify-form-connector'),
            /* translators: %s = error message */
            'errorDeletingMapping' => __('Error deleting mapping: %s', 'inboxify-form-connector'),
            /* translators: %s = error message */
            'errorFetchingFormFields' => __('Error fetching form fields: %s', 'inboxify-form-connector'),
            /* translators: %s = error message */
            'errorLoadingLists' => __('Error loading lists: %s', 'inboxify-form-connector'),
            /* translators: %s = error message */
            'errorConnectingAPI' => __('Error connecting API: %s', 'inboxify-form-connector'),
            /* translators: %s = error message */
            'errorSavingMapping' => __('Error saving mapping: %s', 'inboxify-form-connector')
        ]);

        wp_enqueue_style('inboxify-admin-css', plugins_url('/assets/css/admin.css', __FILE__), [], INBOXIFY_FC_PLUGIN_VERSION);

        $json_path = plugin_dir_path(__FILE__) . 'includes/config/inboxify-fields.json';
        if (file_exists($json_path)) {
            $fields_json = file_get_contents($json_path);
            $fields_array = json_decode($fields_json, true);

            if (is_array($fields_array)) {
                wp_localize_script('inboxify-admin-js', 'inboxifyFieldConfig', $fields_array);
            }
        }
    }
}
add_action('admin_enqueue_scripts', 'inboxify_fc_enqueue_admin_assets');

add_action('admin_menu', function () {
    add_menu_page(
        'Inboxify Form Connector',
        'Form Connector',
        'manage_options',
        'inboxify-form-connector',
        function () {
            include INBOXIFY_FC_PLUGIN_PATH . 'admin/inboxify-page.php';
        },
        'dashicons-email-alt',
        26
    );
});

function inboxify_fc_check_plugin_update() {
    $stored_version = get_option('inboxify_fc_plugin_version');

    if ($stored_version !== INBOXIFY_FC_PLUGIN_VERSION) {
        inboxify_fc_migrate_old_options();

        update_option('inboxify_fc_plugin_version', INBOXIFY_FC_PLUGIN_VERSION);
    }
}
add_action('plugins_loaded', 'inboxify_fc_check_plugin_update');