<?php
if ( ! defined( 'ABSPATH' ) ) exit;

add_action('plugins_loaded', function () {
    if (function_exists('wpcf7')) {
        add_action('wpcf7_before_send_mail', 'inboxify_fc_handle_cf7_submission');
    }
});

function inboxify_fc_handle_cf7_submission($contact_form) {
    $form_id = $contact_form->id();
    $submission = WPCF7_Submission::get_instance();

    if (!$submission) {
        return;
    }

    $posted_data = $submission->get_posted_data();
    $mappings = get_option('inboxify_fc_mappings', []);
    $form_mapping = $mappings['cf7'][$form_id] ?? null;

    if (!$form_mapping) {
        return;
    }

    $list_id = $form_mapping['list_id'] ?? null;
    $field_mapping = $form_mapping['mappings'] ?? [];

    if (!$list_id || empty($field_mapping)) {
        return;
    }

    $payload = [];

    $field_config = inboxify_fc_get_field_config();

    foreach ($field_mapping as $cf7_field => $inboxify_field) {
        if ($inboxify_field === '__none__') {
            continue;
        }

        $value = $posted_data[$cf7_field] ?? null;
        if (is_array($value)) {
            if ($inboxify_field === 'tags') {
                $value = array_map(function ($tag) use ($field_config, $inboxify_field) {
                    $max = $field_config[$inboxify_field]['maxLength'] ?? 32;
                    return mb_substr(trim($tag), 0, $max);
                }, $value);
            } else {
                $value = reset($value);
            }
        }

        if ($value === null || $value === '') {
            continue;
        }

        if ($inboxify_field === 'email' && !filter_var($value, FILTER_VALIDATE_EMAIL)) {
            return;
        }

        if ($inboxify_field === 'sex' && !in_array($value, ['0', '1', '2'])) {
            continue;
        }

        if ($inboxify_field === 'customDate') {
            // phpcs:ignore WordPress.DateTime.RestrictedFunctions.date_date
            $value = date('Y-m-d', strtotime($value));
        }

        $maxLength = $field_config[$inboxify_field]['maxLength'] ?? null;
        if ($maxLength && is_string($value)) {
            $value = mb_substr($value, 0, $maxLength);
        }

        $payload[$inboxify_field] = $value;
    }

    if (!isset($payload['email']) || $payload['email'] === '') {
        return;
    }

    inboxify_fc_send_contact_to_list($list_id, $payload);
}
