<?php
if ( ! defined( 'ABSPATH' ) ) exit;

add_action('plugins_loaded', function () {
    if (function_exists('wpforms')) {
        add_action('wpforms_process_complete', 'inboxify_fc_handle_wpforms_submission', 10, 4);
    }
});

function inboxify_fc_handle_wpforms_submission($fields, $entry, $form_data, $entry_id) {
    $form_id = $form_data['id'] ?? null;

    if (!$form_id) {
        return;
    }

    $posted_data = [];
    foreach ($fields as $field_id => $field) {
        $name = 'field_' . $field_id;
        $posted_data[$name] = $field['value'];
    }

    $mappings     = get_option('inboxify_fc_mappings', []);
    $form_mapping = $mappings['wpforms'][$form_id] ?? null;

    if (!$form_mapping) {
        return;
    }

    $list_id       = $form_mapping['list_id'] ?? null;
    $field_mapping = $form_mapping['mappings'] ?? [];

    if (!$list_id || empty($field_mapping)) {
        return;
    }

    $payload      = [];
    $field_config = inboxify_fc_get_field_config();

    foreach ($field_mapping as $form_field => $inboxify_field) {
        if ($inboxify_field === '__none__') {
            continue;
        }

        $value = $posted_data[$form_field] ?? null;

        if ($inboxify_field === 'tags') {
            if (is_array($value)) {
                $tags = $value;
            } elseif (is_string($value) && str_contains($value, "\n")) {
                $tags = preg_split('/\r\n|\r|\n/', $value);
            } else {
                $tags = [$value];
            }

            $max   = $field_config[$inboxify_field]['maxLength'] ?? 32;
            $value = array_map(function ($tag) use ($max) {
                return mb_substr(trim($tag), 0, $max);
            }, $tags);
        }

        if ($value === null || $value === '') {
            continue;
        }

        if ($inboxify_field === 'email' && !filter_var($value, FILTER_VALIDATE_EMAIL)) {
            return;
        }

        if ($inboxify_field === 'sex' && !in_array($value, ['0', '1', '2'])) {
            continue;
        }

        if ($inboxify_field === 'customDate') {
            // phpcs:ignore WordPress.DateTime.RestrictedFunctions.date_date
            $value = date('Y-m-d', strtotime($value));
        }

        $maxLength = $field_config[$inboxify_field]['maxLength'] ?? null;
        if ($maxLength && is_string($value)) {
            $value = mb_substr($value, 0, $maxLength);
        }

        $payload[$inboxify_field] = $value;
    }

    if (!isset($payload['email']) || $payload['email'] === '') {
        return;
    }

    if (empty($payload)) {
        return;
    }

    inboxify_fc_send_contact_to_list($list_id, $payload);
}
